module DispScore (clk, reset, screenx, screeny, outleft, outright, 
			romaddrx, romaddry, romselect, drawscore) ;

input clk ;
input reset;
input outleft;
input outright;
input [9:0] screenx;
input [8:0] screeny;
output [3:0] romaddrx;
output [3:0] romaddry;
output [3:0] romselect;
output drawscore;

reg [3:0] _romaddrx;		// the address for the rom output
assign romaddrx = _romaddrx;	
reg [3:0] _romaddry;
assign romaddry = _romaddry;
reg [3:0] _romselect;		// select which number to display
assign romselect = _romselect;
reg _drawscore;
assign drawscore = _drawscore;


reg [3:0] p1scoredigit1;
reg [3:0] p1scoredigit2;
reg [3:0] p1scoredigit3;
reg [3:0] p2scoredigit1;
reg [3:0] p2scoredigit2;
reg [3:0] p2scoredigit3;

always @(posedge clk) begin
	if(reset) begin
		p1scoredigit1 = 0;
		p1scoredigit2 = 0;
		p1scoredigit3 = 0;
		p2scoredigit1 = 0;
		p2scoredigit2 = 0;
		p2scoredigit3 = 0;
		_drawscore <=0;	
		_romaddrx <= 0;
		_romaddry <= 0;
		_romselect <= 0;
					
	end
	else begin
		if(outleft) begin
			p2scoredigit1 = p2scoredigit1 + 1;
			if(p2scoredigit1 > 9) begin
				p2scoredigit1 = 0;
				p2scoredigit2 = p2scoredigit2 + 1;
				if(p2scoredigit2 > 9) begin
					p2scoredigit2 = 0;
					p2scoredigit3 = p2scoredigit3 + 1;
					if(p2scoredigit3 > 9)
						p2scoredigit3 = 0;
				end								
			end
		end
		if(outright) begin
			p1scoredigit1 = p1scoredigit1 + 1;
			if(p1scoredigit1 > 9) begin
				p1scoredigit1 = 0;
				p1scoredigit2 = p1scoredigit2 + 1;
				if(p1scoredigit2 > 9) begin
					p1scoredigit2 = 0;
					p1scoredigit3 = p1scoredigit3 + 1;
					if(p1scoredigit3 > 9)
						p1scoredigit3 = 0;
				end								
			end

		end 
		if(screeny >= 464) begin
			_romaddry <= screeny - 464;
			if(screenx >= 16 & screenx < 32) begin // draw first digit of player1 score
				_drawscore <= 1;	
				_romaddrx <= screenx - 16;
				_romselect <= p1scoredigit3; 
			end
			else if(screenx >= 32 & screenx < 48) begin // draw second digit of player1 score
				_drawscore <= 1;	
				_romaddrx <= screenx - 32;
				_romselect <= p1scoredigit2; 
			end 
			else if (screenx >= 48 & screenx < 64) begin // draw third digit of player1 score
				_drawscore <= 1;	
				_romaddrx <= screenx - 48;
				_romselect <= p1scoredigit1; 
			end
			else if (screenx >= 576 & screenx < 592) begin // draw first digit of player2 score
				_drawscore <= 1;
				_romaddrx <= screenx - 576;
				_romselect <= p2scoredigit3; 
			end
			else if (screenx >= 592 & screenx < 608) begin // draw second digit of player2 score
				_drawscore <= 1;
				_romaddrx <= screenx - 592;
				_romselect <= p2scoredigit2;
			end
			else if (screenx >= 608 & screenx < 624) begin // draw third digit of player3 score
				_drawscore <= 1;
				_romaddrx <= screenx - 608;
				_romselect <= p2scoredigit1;
			end
			else begin
				_drawscore <= 0;
				_romaddrx <= 0;
				_romaddry <= 0;
				_romselect <= 0;
			end
		end
		else begin
			_drawscore <= 0;
			_romaddrx <= 0;
			_romaddry <= 0;
			_romselect <= 0;
		end
	end
	
	
end

endmodule 
