module pmover (clk, reset, keyup, keydown, keyleft, keyright, freezekey, start, 
               yposition, xposition, xspeed, yspeed, processing) ;
input clk ;
input reset ;
input keyup ;
input keydown ;
input keyleft;
input keyright;
input freezekey;
input start;

output [8:0] yposition ;
output [8:0] xposition;
output [2:0] xspeed;
output [3:0] yspeed;
output processing;

// add your declarations here
reg [8:0] _xposition, _yposition;
assign yposition = _yposition;
assign xposition = _xposition;

reg [2:0] _xspeed;
reg [3:0] _yspeed;
assign xspeed = _xspeed;
assign yspeed = _yspeed;

reg [1:0] upDown;         // UpDown = 0 move down
			  //	    = 1 move not moving
			  // 	    = 2 move up
reg [1:0] leftRight; 	  // leftRight = 0 move left
 			  //	       = 1 move not moving
			  // 	       = 2 move right

reg updatePos;
reg correctPos;

assign processing = start | updatePos | correctPos;


always@(posedge clk)begin
	if(reset) begin
		upDown <= 1;
		leftRight <= 1;
	end else begin
		if(keyup) begin
			upDown <= 2;
		end
		else if(keydown) begin
			upDown <= 0;
		end
		else if(keyleft) begin
			leftRight <= 0;
		end
		else if(keyright) begin
			leftRight <= 2;
		end
		else if (freezekey) begin
			leftRight <= 1;
			upDown <=1;
		end
	end
end

always@(posedge clk) begin
	if(reset)begin
		updatePos <= 0;
		correctPos <= 0;
		_yposition <= 216;
		_xposition <= 160;
		_xspeed <= 0;
		_yspeed <= 0;
	end
	else begin
		updatePos <= 0;
		correctPos <= 0;
		if(start) begin
			//update the speed
			if(upDown == 0 & _yspeed !=4'b0111) //player wants to move down
				_yspeed <= _yspeed +1;
			else if(upDown == 2 & _yspeed != 4'b1001) //player wants to move up
				_yspeed <= _yspeed -1 ;
			else if(upDown == 1 & (_yspeed[3] ==0 & _yspeed > 0))
				_yspeed <= _yspeed -1;
			else if(upDown == 1 & (_yspeed[3] ==1))
				_yspeed <= _yspeed +1;

			if(leftRight == 2 & _xspeed != 3'b011) //player wants to move right
				_xspeed <= _xspeed +1;
			else if(leftRight == 0 & _xspeed != 3'b101)
				_xspeed <= _xspeed -1 ;
			else if(leftRight == 1 & (_xspeed[2] ==0 & _xspeed > 0))
				_xspeed <= _xspeed -1;
			else if(leftRight == 1 & _xspeed[2] ==1)
				_xspeed <= _xspeed +1;
			updatePos <= 1;
		end
		else if(updatePos) begin
			_yposition <= _yposition + {_yspeed[3],_yspeed[3],_yspeed[3],_yspeed[3],_yspeed[3],_yspeed}; 
			_xposition <= _xposition + {_xspeed[2],_xspeed[2],_xspeed[2],_xspeed[2],_xspeed[2],_xspeed[2],_xspeed};
			updatePos <= 0;
			correctPos <= 1;
		end
		else if(correctPos) begin
			if(_yposition < 10 ) begin
				_yposition <= 10;
				_yspeed <= 0;
			end
			//else if(_yposition > 439) begin
			//	_yposition <= 439;
			else if(_yposition > 417) begin
				_yposition <= 417;
				_yspeed <= 0;
			end
			if(_xposition < 10 ) begin
				_xposition <= 10;
				_xspeed <= 0;
			end
			else if(_xposition > 301) begin
				_xposition <= 301;
				_xspeed <= 0;
			end
		end
	end
end
endmodule 
